@@ -6,7 +6,12 @@ class MetaConfig(type):
     def __init__(cls, name, bases, dict):
         super().__init__(name, bases, dict)
         cls.name = name
-        cls._dict = dict
+        cls._dict = {}
+        for base in bases:
+            if not hasattr(base, '_dict'):
+                continue
+            cls._dict.update(base._dict)
+        cls._dict.update(dict)
 
     def __getattribute__(cls, name):
         '''
@@ -14,7 +19,7 @@ class MetaConfig(type):
 
         Fall back to getattr for everything else
         '''
-        if name in ('__annotations__', 'name', '_dict', '_to_int', '_to_bool', '_to_float', '_to_dict'):
+        if name in ('name',) or name.startswith('_'):
             return super().__getattribute__(name)
         raise AttributeError('Fallback to environment')
 
